==> GotoBLAS-1.00.tar.gz: GotoBLAS/common_level1.h <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#ifndef ASSEMBLER

float  sdot_k  (long, float *, long,   float *,  long);
double ddot_k  (long, double *,long,   double *, long);

double dsdot_k (long, float  *,long,   float  *, long);
float  sdsdot_k(long, float   ,float *, long,  float *, long);

float   cdotc_k (long, float  *, long, float  *, long);
float   cdotu_k (long, float  *, long, float  *, long);
double  zdotc_k (long, double *, long, double *, long);
double  zdotu_k (long, double *, long, double *, long);

int    saxpy_k (long, long, long, float, 
	       float  *, long, float  *, long, float  *, long);
int    daxpy_k (long, long, long, double, 
	       double *, long, double *, long, double *, long);
int    caxpy_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpy_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);

int    scopy_k(long, float  *, long, float  *, long);
int    dcopy_k(long, double *, long, double *, long);
int    ccopy_k(long, float  *, long, float  *, long);
int    zcopy_k(long, double *, long, double *, long);

int    sswap_k (long, long, long, float, 
	       float  *, long, float  *, long, float *, long);
int    dswap_k (long, long, long, double, 
	       double *, long, double *, long, double*, long);
int    cswap_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float *, long);
int    zswap_k (long, long, long, double, double,
	       double *, long, double *, long, double*, long);

float  sasum_k (long, float  *, long);
double dasum_k (long, double *, long);
float  scasum_k(long, float  *, long);
double dzasum_k(long, double *, long);

float  samax_k (long, float  *, long);
double damax_k (long, double *, long);
float  scamax_k (long, float  *, long);
double dzamax_k (long, double *, long);

float  samin_k (long, float  *, long);
double damin_k (long, double *, long);
float  camin_k (long, float  *, long);
double zamin_k (long, double *, long);

long   isamax_k(long, float  *, long);
long   idamax_k(long, double *, long);
long   icamax_k(long, float  *, long);
long   izamax_k(long, double *, long);

long   isamin_k(long, float  *, long);
long   idamin_k(long, double *, long);
long   icamin_k(long, float  *, long);
long   izamin_k(long, double *, long);

float  smax_k (long, float  *, long);
double dmax_k (long, double *, long);
float  cmax_k (long, float  *, long);
double zmax_k (long, double *, long);

float  smin_k (long, float  *, long);
double dmin_k (long, double *, long);
float  cmin_k (long, float  *, long);
double zmin_k (long, double *, long);

long   ismax_k(long, float  *, long);
long   idmax_k(long, double *, long);
long   icmax_k(long, float  *, long);
long   izmax_k(long, double *, long);

long   ismin_k(long, float  *, long);
long   idmin_k(long, double *, long);
long   icmin_k(long, float  *, long);
long   izmin_k(long, double *, long);

int    sscal_k(long, long, long, float, 
	      float *, long, float *, long,  float  *, long);
int    dscal_k(long, long, long, double, 
	      double *, long, double *, long,  double  *, long);
int    cscal_k(long, long, long, float, float,
	      float *, long, float *, long,  float  *, long);
int    zscal_k(long, long, long, double, double,
	      double *, long, double *, long,  double  *, long);
int    csscal_k(long, long, long, float, float,
	       float *, long, float *, long,  float  *, long);
int    zdscal_k(long, long, long, double, double,
	       double *, long, double *, long,  double  *, long);

float  snrm2_k (long, float,  float  *, long);
double dnrm2_k (long, double, double *, long);
float  scnrm2_k(long, float,  float  *, long);
double dznrm2_k(long, double, double *, long);

int    srot_k (long *, float  *, long *, float  *, long *, float  *, float  *);
int    drot_k (long *, double *, long *, double *, long *, double *, double *);
int    csrot_k(long *, float  *, long *, float  *, long *, float  *, float  *);
int    zdrot_k(long *, double *, long *, double *, long *, double *, double *);

int    srotg_k(float  *, float  *, float  *, float  *);
int    drotg_k(double *, double *, double *, double *);
int    crotg_k(float  *, float  *, float  *, float  *);
int    zrotg_k(double *, double *, double *, double *);

int    srotmg_k(float  *, float  *, float  *, float  *, float  *);
int    drotmg_k(double *, double *, double *, double *, double *);

int    srotm_k (long, float,  long, float,  long, float);
int    drotm_k (long, double, long, double, long, double);

#ifdef DOUBLE

#define DOT_K    ddot_k
#define ZDOTC_K  zdotc_k
#define ZDOTU_K  zdotu_k

#define SCAL_K   dscal_k
#define ZSCAL_K  zscal_k

#define SWAP_K   dswap_k
#define ZSWAP_K  zswap_k

#define AXPY_K	 daxpy_k
#define ZAXPY_K  zaxpy_k

#define  COPY_K  dcopy_k
#define ZCOPY_K  zcopy_k

#define IAMAX_K  idamax_k
#define IZAMAX_K izamax_k

#define IAMIN_K  idamin_k
#define IZAMIN_K izamin_k

#else

#define DOT_K    sdot_k
#define ZDOTC_K  cdotc_k
#define ZDOTU_K  cdotu_k

#define SCAL_K   sscal_k
#define ZSCAL_K  cscal_k

#define SWAP_K   sswap_k
#define ZSWAP_K  cswap_k

#define AXPY_K	 saxpy_k
#define ZAXPY_K  caxpy_k

#define  COPY_K   scopy_k
#define ZCOPY_K   ccopy_k

#define IAMAX_K   isamax_k
#define IZAMAX_K  icamax_k

#define IAMIN_K   isamin_k
#define IZAMIN_K  icamin_k

#endif

#endif

==> GotoBLAS-1.08.tar.gz: GotoBLAS/common_level1.h <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#ifndef ASSEMBLER

float  sdot_k  (long, float *, long,   float *,  long);
double ddot_k  (long, double *,long,   double *, long);

double dsdot_k (long, float  *,long,   float  *, long);
float  sdsdot_k(long, float   ,float *, long,  float *, long);

float   cdotc_k (long, float  *, long, float  *, long);
float   cdotu_k (long, float  *, long, float  *, long);
double  zdotc_k (long, double *, long, double *, long);
double  zdotu_k (long, double *, long, double *, long);

int    saxpy_k (long, long, long, float, 
	       float  *, long, float  *, long, float  *, long);
int    daxpy_k (long, long, long, double, 
	       double *, long, double *, long, double *, long);
int    caxpy_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpy_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);
int    caxpyc_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float  *, long);
int    zaxpyc_k (long, long, long, double, double,
	       double *, long, double *, long, double *, long);

int    scopy_k(long, float  *, long, float  *, long);
int    dcopy_k(long, double *, long, double *, long);
int    ccopy_k(long, float  *, long, float  *, long);
int    zcopy_k(long, double *, long, double *, long);

int    sswap_k (long, long, long, float, 
	       float  *, long, float  *, long, float *, long);
int    dswap_k (long, long, long, double, 
	       double *, long, double *, long, double*, long);
int    cswap_k (long, long, long, float,  float,
	       float  *, long, float  *, long, float *, long);
int    zswap_k (long, long, long, double, double,
	       double *, long, double *, long, double*, long);

#ifdef USE_EXTENDED_DOUBLE
long double qasum_k (long, long double *, long);
long double qxasum_k(long, long double *, long);
long double qamax_k (long, long double *, long);
long double qxamax_k(long, long double *, long);
#endif

float  sasum_k (long, float  *, long);
double dasum_k (long, double *, long);
float  scasum_k(long, float  *, long);
double dzasum_k(long, double *, long);

float  samax_k (long, float  *, long);
double damax_k (long, double *, long);
float  scamax_k (long, float  *, long);
double dzamax_k (long, double *, long);

float  samin_k (long, float  *, long);
double damin_k (long, double *, long);
float  camin_k (long, float  *, long);
double zamin_k (long, double *, long);

long   isamax_k(long, float  *, long);
long   idamax_k(long, double *, long);
long   icamax_k(long, float  *, long);
long   izamax_k(long, double *, long);

long   isamin_k(long, float  *, long);
long   idamin_k(long, double *, long);
long   icamin_k(long, float  *, long);
long   izamin_k(long, double *, long);

float  smax_k (long, float  *, long);
double dmax_k (long, double *, long);
float  cmax_k (long, float  *, long);
double zmax_k (long, double *, long);

float  smin_k (long, float  *, long);
double dmin_k (long, double *, long);
float  cmin_k (long, float  *, long);
double zmin_k (long, double *, long);

long   ismax_k(long, float  *, long);
long   idmax_k(long, double *, long);
long   icmax_k(long, float  *, long);
long   izmax_k(long, double *, long);

long   ismin_k(long, float  *, long);
long   idmin_k(long, double *, long);
long   icmin_k(long, float  *, long);
long   izmin_k(long, double *, long);

int    sscal_k(long, long, long, float, 
	      float *, long, float *, long,  float  *, long);
int    dscal_k(long, long, long, double, 
	      double *, long, double *, long,  double  *, long);
int    cscal_k(long, long, long, float, float,
	      float *, long, float *, long,  float  *, long);
int    zscal_k(long, long, long, double, double,
	      double *, long, double *, long,  double  *, long);
int    csscal_k(long, long, long, float, float,
	       float *, long, float *, long,  float  *, long);
int    zdscal_k(long, long, long, double, double,
	       double *, long, double *, long,  double  *, long);

float  snrm2_k (long, float,  float  *, long);
double dnrm2_k (long, double, double *, long);
float  scnrm2_k(long, float,  float  *, long);
double dznrm2_k(long, double, double *, long);

int    srot_k (long, float  *, long, float  *, long, float , float );
int    drot_k (long, double *, long, double *, long, double, double);
int    csrot_k(long, float  *, long, float  *, long, float , float );
int    zdrot_k(long, double *, long, double *, long, double, double);

int    srotg_k(float  *, float  *, float  *, float  *);
int    drotg_k(double *, double *, double *, double *);
int    crotg_k(float  *, float  *, float  *, float  *);
int    zrotg_k(double *, double *, double *, double *);

int    srotmg_k(float  *, float  *, float  *, float  *, float  *);
int    drotmg_k(double *, double *, double *, double *, double *);

int    srotm_k (long, float,  long, float,  long, float);
int    drotm_k (long, double, long, double, long, double);

#ifdef DOUBLE

#define DOT_K    ddot_k
#define ZDOTC_K  zdotc_k
#define ZDOTU_K  zdotu_k

#define SCAL_K   dscal_k
#define ZSCAL_K  zscal_k

#define SWAP_K   dswap_k
#define ZSWAP_K  zswap_k

#define AXPY_K	 daxpy_k
#define ZAXPY_K  zaxpy_k
#define ZAXPYC_K  zaxpyc_k

#define  COPY_K  dcopy_k
#define ZCOPY_K  zcopy_k

#define IAMAX_K  idamax_k
#define IZAMAX_K izamax_k

#define IAMIN_K  idamin_k
#define IZAMIN_K izamin_k

#define ROT_K	 drot_k
#define ZROT_K	 zrot_k

#else

#define DOT_K    sdot_k
#define ZDOTC_K  cdotc_k
#define ZDOTU_K  cdotu_k

#define SCAL_K   sscal_k
#define ZSCAL_K  cscal_k

#define SWAP_K   sswap_k
#define ZSWAP_K  cswap_k

#define AXPY_K	 saxpy_k
#define ZAXPY_K  caxpy_k
#define ZAXPYC_K  caxpyc_k

#define  COPY_K   scopy_k
#define ZCOPY_K   ccopy_k

#define IAMAX_K   isamax_k
#define IZAMAX_K  icamax_k

#define IAMIN_K   isamin_k
#define IZAMIN_K  icamin_k

#define ROT_K	 srot_k
#define ZROT_K	 crot_k

#endif

#endif
